<?php

namespace Drupal\pagerer;

use Drupal\Core\Pager\Pager;

/**
 * Pagerer pager value object.
 */
class Pagerer extends Pager {

  /**
   * The pager element.
   *
   * This is the index used by query extenders to identify the query
   * to be paged, and reflected in the 'page=x,y,z' query parameter
   * of the HTTP request.
   *
   * @var int
   */
  protected $element;

  /**
   * The route name.
   *
   * @var string
   */
  protected $routeName;

  /**
   * The route parameters.
   *
   * @var string[]
   */
  protected $routeParameters = [];

  /**
   * The pager adaptive keys.
   *
   * @var string
   */
  protected $adaptiveKeys;

  /**
   * Gets the route name for this pager.
   *
   * @return string
   *   The route name.
   */
  public function getRouteName() {
    return $this->routeName;
  }

  /**
   * Sets the route name for this pager.
   *
   * @param string $route_name
   *   The route name.
   *
   * @return $this
   */
  public function setRouteName($route_name) {
    $this->routeName = $route_name;
    return $this;
  }

  /**
   * Gets the route parameters for this pager.
   *
   * @return string[]
   *   The route parameters.
   */
  public function getRouteParameters() {
    return $this->routeParameters;
  }

  /**
   * Sets the route parameters for this pager.
   *
   * @param string[] $route_parameters
   *   The route parameters.
   *
   * @return $this
   */
  public function setRouteParameters(array $route_parameters) {
    $this->routeParameters = $route_parameters;
    return $this;
  }

  /**
   * Gets the pager element.
   *
   * @return int
   *   The pager element.
   */
  public function getElement() {
    return $this->element;
  }

  /**
   * Sets the pager element.
   *
   * @param int $element
   *   The pager element.
   *
   * @return $this
   */
  public function setElement($element) {
    $this->element = $element;
    return $this;
  }

  /**
   * Gets last page in the pager (zero-index).
   *
   * @return int
   *   The index of the last page in the pager.
   */
  public function getLastPage() {
    return $this->totalPages - 1;
  }

  /**
   * Gets the adaptive keys of this pager.
   *
   * Used by the Adaptive pager style.
   *
   * @return string
   *   The adaptive keys string, in the format 'L.R.X', where L is the
   *   adaptive lock to left page, R is the adaptive lock to right page,
   *   and X is the adaptive center lock for calculation of neighborhood.
   */
  public function getAdaptiveKeys() {
    return $this->adaptiveKeys;
  }

  /**
   * Sets the adaptive keys of this pager.
   *
   * Used by the Adaptive pager style.
   *
   * @param string $adaptive_keys
   *   The adaptive keys string, in the format 'L.R.X', where L is the
   *   adaptive lock to left page, R is the adaptive lock to right page,
   *   and X is the adaptive center lock for calculation of neighborhood.
   *
   * @return $this
   */
  public function setAdaptiveKeys($adaptive_keys) {
    $this->adaptiveKeys = $adaptive_keys;
    return $this;
  }

}
