<?php

namespace Drupal\pagerer;

use Drupal\Core\Pager\PagerParameters;

/**
 * Provides extended pager information contained within the current request.
 */
class PagererParameters extends PagerParameters {

  /**
   * Returns the current adaptive keys for a pager element.
   *
   * @param int $pager_id
   *   (optional) An integer to distinguish between multiple pagers on one page.
   *
   * @return string|null
   *   The adaptive keys string, in the format 'L.R.X', where L is the
   *   adaptive lock to left page, R is the adaptive lock to right page,
   *   and X is the adaptive center lock for calculation of neighborhood.
   */
  public function findAdaptiveKeys($pager_id = 0) {
    $request = $this->requestStack->getCurrentRequest();
    if ($request) {
      $page_ak = $request->query->get('page_ak', '');
      if (!empty($page_ak)) {
        // A 'page_ak' query parameter exists in the calling URL.
        $adaptive_keys = explode(',', $page_ak);
        if (isset($adaptive_keys[$pager_id])) {
          return $adaptive_keys[$pager_id];
        }
      }
    }
    return NULL;
  }

}
